# Lazy Stream

Lazy Stream is a library for lazy evaluation in Python. It is inspired by the Scala Stream class.

Lazy Stream allows you to store and chain operations on a finite or infinite sequence of values. The final result will only be computed when needed, for better memory and performance over conventional Python lists.
